package org.qatools.util;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import org.apache.commons.net.ftp.FTPClient;
import org.apache.log4j.Logger;
import org.qatools.local.LocalFile;
import org.qatools.remote.RemoteConn;
import org.qatools.remote.RemoteFile;
/**
 * 
 * @author hockeyeh
 *
 */
public class FtpUtil extends QAToolsUtil {
	private static Logger logger = Logger.getLogger(FtpUtil.class);
	private static FTPClient client = new FTPClient();
	 
	// -------------------------------------------------------------
	// ----- connect
	// -------------------------------------------------------------

	/**
	 * 
	 * @param remoteConnection
	 */
	protected static void connect(RemoteConn remoteConnection) {
	    try {
	        client.connect(remoteConnection.getHost());
	        boolean login = client.login(remoteConnection.getUser(), remoteConnection.getPassword());

	        if (login) {
	            logger.debug("Login (" + remoteConnection.getUser () + "@" + remoteConnection.getHost() + ") PASS");
	            boolean logout = client.logout();
	            if (logout) {
	                logger.debug("Logout (" + remoteConnection.getUser () + "@" + remoteConnection.getHost() + ") PASS");
	            } else {
	                logger.error("Logout (" + remoteConnection.getUser () + "@" + remoteConnection.getHost() + ") FAIL");
	            }
	        } else {
	            logger.error("Login (" + remoteConnection.getUser () + "@" + remoteConnection.getHost() + ") FAIL");
	        }

	    } catch (IOException e) {
	        e.printStackTrace();
	    } finally {
	        try {
	            client.disconnect();
	        } catch (IOException e) {
	            e.printStackTrace();
	        }
	    }	// finally

	}	// connect
	
	// -------------------------------------------------------------
	// ----- download
	// -------------------------------------------------------------

	/**
	 * 
	 * @param remoteFile
	 */
	public static void download(RemoteFile remoteFile) {
		FileOutputStream fos = null;
		 
        try {
            client.connect(remoteFile.getHost());
            boolean login = client.login(remoteFile.getUser(), remoteFile.getPassword());
            if (login) {
                logger.debug("Login (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ") PASS");
            } else {
                logger.error("Login (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ") FAIL");
                return;
            }

            //
            // Setup the local file
            //
            LocalFile filename = new LocalFile(remoteFile.getFilename());
            fos = new FileOutputStream(filename.getFullPath());
 
            //
            // Download remote file from FTP server
            //
            //client.retrieveFile("/" + filename, fos);
            boolean retrieve = client.retrieveFile(remoteFile.getFullPath(), fos);
            if (retrieve) {
                logger.debug("Retrieve (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ":" + remoteFile.getFullPath () + ") PASS");
            } else {
                logger.debug("Retrieve (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ":" + remoteFile.getFullPath () + ") FAIL");
            }
            
            boolean logout = client.logout();
            if (logout) {
                logger.debug("Logout (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ") PASS");
            } else {
                logger.error("Logout (" + remoteFile.getUser () + "@" + remoteFile.getHost() + ") FAIL");
            }

            
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (fos != null) {
                    fos.close();
                }
                client.disconnect();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }		
	}	// download

	// -------------------------------------------------------------
	// ----- 
	// -------------------------------------------------------------

	/**
	 * 
	 * @param remoteFile
	 */
	private static void upload(LocalFile localFile, RemoteFile remoteFile) {
	    FileInputStream fis = null;
	    
        try {
            client.connect(remoteFile.getHost());
            client.login(remoteFile.getUser(), remoteFile.getPassword());
 
            //
            // Create an InputStream of the file to be uploaded
            //
            String filename = localFile.getFullPath();
            fis = new FileInputStream(filename);
 
            //
            // Store file to server
            //
            client.storeFile(remoteFile.getFullPath(), fis);
            client.logout();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (fis != null) {
                    fis.close();
                }
                client.disconnect();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }		
	} //upload

    
}	// FtpUtil





